Files
TheRock/rocm-systems/projects/hip-tests/catch/unit/graph/graph_tests_common.hh
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

54 lines
1.8 KiB
C++

/*
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
#pragma once
#include <stddef.h>
#include <hip/hip_runtime_api.h>
#include <resource_guards.hh>
template <typename F> void GraphAddNodeCommonNegativeTests(F f, hipGraph_t graph) {
hipGraphNode_t node = nullptr;
SECTION("graph == nullptr") {
HIP_CHECK_ERROR(f(&node, nullptr, nullptr, 0), hipErrorInvalidValue);
}
SECTION("node == nullptr") {
HIP_CHECK_ERROR(f(nullptr, graph, nullptr, 0), hipErrorInvalidValue);
}
SECTION("dependencies == nullptr with size != 0") {
HIP_CHECK_ERROR(f(&node, graph, nullptr, 1), hipErrorInvalidValue);
}
// Disabled on AMD due to defect - EXSWHTEC-202
#if HT_NVIDIA
SECTION("Node in dependency is from different graph") {
hipGraph_t other_graph = nullptr;
HIP_CHECK(hipGraphCreate(&other_graph, 0));
hipGraphNode_t other_node = nullptr;
HIP_CHECK(hipGraphAddEmptyNode(&other_node, other_graph, nullptr, 0));
hipGraphNode_t node = nullptr;
HIP_CHECK(hipGraphAddEmptyNode(&node, graph, nullptr, 0));
HIP_CHECK_ERROR(f(&node, graph, &other_node, 1), hipErrorInvalidValue);
HIP_CHECK(hipGraphDestroy(other_graph));
}
#endif
// Disabled on AMD due to defect - EXSWHTEC-201
#if HT_NVIDIA
SECTION("Duplicate node in dependencies") {
hipGraphNode_t dep_node = nullptr;
// Need to create two nodes to avoid overlap with Invalid numNodes case
// First one is left dangling as the graph will be destroyed after the section anyway
HIP_CHECK(hipGraphAddEmptyNode(&dep_node, graph, nullptr, 0));
HIP_CHECK(hipGraphAddEmptyNode(&dep_node, graph, nullptr, 0));
hipGraphNode_t deps[] = {dep_node, dep_node};
HIP_CHECK_ERROR(f(&node, graph, deps, 2), hipErrorInvalidValue);
}
#endif
}